@@ -8,6 +8,7 @@ extern crate env_logger;
 
 use gitlab::GitLab;
 // use gitlab::Pagination;
+use gitlab::Lister;
 
 use gitlab::errors::*;
 
@@ -54,7 +55,10 @@ fn run() -> Result<()> {
     };
 
     let gl = GitLab::new(&hostname, &token).chain_err(|| "failure to create GitLab instance")?;
-    // let gl = GitLab::new(&hostname, &token).chain_err(|| "failure to create GitLab instance")?.scheme("http").port(80);
+    // let gl = GitLab::new(&hostname, &token)
+    //     .chain_err(|| "failure to create GitLab instance")?
+    //     .scheme("http")
+    //     .port(80);
     // let gl = gl.scheme("http").port(80);
 
     let projects = gl.projects().list().chain_err(|| "cannot get projects")?;
@@ -74,5 +78,37 @@ fn run() -> Result<()> {
         .chain_err(|| "cannot get projects")?;
     println!("projects: {:?}", projects);
 
+    let project = gl.projects()
+        .id(gitlab::projects::ListingId::Id(9))
+        .list()
+        .chain_err(|| "failure to find project")?;
+    println!("project: {:?}", project);
+
+    let issues = project.issues(&gl)
+        .list()
+        .chain_err(|| "failure to find project's issues")?;
+    println!("issues: {:?}", issues);
+
+    let merge_requests = project.merge_requests(&gl)
+        .list()
+        .chain_err(|| "failure to find project's merge_requests")?;
+    println!("merge_requests: {:?}", merge_requests);
+
+    let issues = gl.projects()
+        .id(gitlab::projects::ListingId::Id(9))
+        .issues()
+        .chain_err(|| "failure to build a gitlab::issues::project::IssuesLister")?
+        .list()
+        .chain_err(|| "failure to find issues")?;
+    println!("issues: {:?}", issues);
+
+    let merge_requests = gl.projects()
+        .id(gitlab::projects::ListingId::Id(9))
+        .merge_requests()
+        .chain_err(|| "failure to build a gitlab::merge_requests::project::IssuesLister")?
+        .list()
+        .chain_err(|| "failure to find merge requests")?;
+    println!("merge_requests: {:?}", merge_requests);
+
     Ok(())
 }
