@@ -42,7 +42,7 @@ impl<'a> GroupLister<'a> {
         let query = self.build_query();
         debug!("query: {:?}", query);
 
-        self.gl.get(&query).chain_err(|| format!("cannot get query {}", query))
+        self.gl.get(&query, None, None).chain_err(|| format!("cannot get query {}", query))
     }
 }
 
